@@ -49,20 +49,24 @@ class Node(_common.ListMixin, resource.Resource):
     commit_jsonpatch = True
 
     _query_mapping = resource.QueryParameters(
-        'associated', 'conductor_group', 'driver', 'fault', 'fields',
+        'associated', 'conductor_group', 'driver', 'fault',
         'provision_state', 'resource_class',
+        fields={'name': 'fields', 'type': _common.comma_separated_list},
         instance_id='instance_uuid',
         is_maintenance='maintenance',
     )
 
-    # The conductor_group field introduced in 1.46 (Rocky).
-    _max_microversion = '1.46'
+    # The conductor field introduced in 1.49 (Stein).
+    _max_microversion = '1.49'
 
     # Properties
     #: The UUID of the chassis associated wit this node. Can be empty or None.
     chassis_id = resource.Body("chassis_uuid")
     #: The current clean step.
     clean_step = resource.Body("clean_step")
+    #: Hostname of the conductor currently handling this ndoe. Added in API
+    # microversion 1.49.
+    conductor = resource.Body("conductor")
     #: Conductor group this node is managed by. Added in API microversion 1.46.
     conductor_group = resource.Body("conductor_group")
     #: Timestamp at which the node was last updated.
@@ -90,11 +94,16 @@ class Node(_common.ListMixin, resource.Resource):
     instance_info = resource.Body("instance_info")
     #: UUID of the nova instance associated with this node.
     instance_id = resource.Body("instance_uuid")
+    #: Override enabling of automated cleaning. Added in API microversion 1.47.
+    is_automated_clean_enabled = resource.Body("automated_clean", type=bool)
     #: Whether console access is enabled on this node.
     is_console_enabled = resource.Body("console_enabled", type=bool)
     #: Whether node is currently in "maintenance mode". Nodes put into
     #: maintenance mode are removed from the available resource pool.
     is_maintenance = resource.Body("maintenance", type=bool)
+    # Whether the node is protected from undeploying. Added in API microversion
+    # 1.48.
+    is_protected = resource.Body("protected", type=bool)
     #: Any error from the most recent transaction that started but failed to
     #: finish.
     last_error = resource.Body("last_error")
@@ -117,6 +126,8 @@ class Node(_common.ListMixin, resource.Resource):
     #: Physical characteristics of the node. Content populated by the service
     #: during inspection.
     properties = resource.Body("properties", type=dict)
+    # The reason why this node is protected. Added in API microversion 1.48.
+    protected_reason = resource.Body("protected_reason")
     #: The current provisioning state of the node.
     provision_state = resource.Body("provision_state")
     #: The current RAID configuration of the node.
@@ -266,7 +277,8 @@ class Node(_common.ListMixin, resource.Resource):
         :param target: Provisioning action, e.g. ``active``, ``provide``.
             See the Bare Metal service documentation for available actions.
         :param config_drive: Config drive to pass to the node, only valid
-            for ``active` and ``rebuild`` targets.
+            for ``active` and ``rebuild`` targets. You can use functions from
+            :mod:`openstack.baremetal.configdrive` to build it.
         :param clean_steps: Clean steps to execute, only valid for ``clean``
             target.
         :param rescue_password: Password for the rescue operation, only valid
@@ -445,7 +457,7 @@ class Node(_common.ListMixin, resource.Resource):
                 "the last error is %(error)s" %
                 {'node': self.id, 'error': self.last_error})
 
-    def attach_vif(self, session, vif_id):
+    def attach_vif(self, session, vif_id, retry_on_conflict=True):
         """Attach a VIF to the node.
 
         The exact form of the VIF ID depends on the network interface used by
@@ -456,6 +468,10 @@ class Node(_common.ListMixin, resource.Resource):
         :param session: The session to use for making this request.
         :type session: :class:`~keystoneauth1.adapter.Adapter`
         :param string vif_id: Backend-specific VIF ID.
+        :param retry_on_conflict: Whether to retry HTTP CONFLICT errors.
+            This can happen when either the VIF is already used on a node or
+            the node is locked. Since the latter happens more often, the
+            default value is True.
         :return: ``None``
         :raises: :exc:`~openstack.exceptions.NotSupported` if the server
             does not support the VIF API.
@@ -468,12 +484,13 @@ class Node(_common.ListMixin, resource.Resource):
         request = self._prepare_request(requires_id=True)
         request.url = utils.urljoin(request.url, 'vifs')
         body = {'id': vif_id}
+        retriable_status_codes = _common.RETRIABLE_STATUS_CODES
+        if not retry_on_conflict:
+            retriable_status_codes = set(retriable_status_codes) - {409}
         response = session.post(
             request.url, json=body,
             headers=request.headers, microversion=version,
-            # NOTE(dtantsur): do not retry CONFLICT, it's a valid status code
-            # in this API when the VIF is already attached to another node.
-            retriable_status_codes=[503])
+            retriable_status_codes=retriable_status_codes)
 
         msg = ("Failed to attach VIF {vif} to bare metal node {node}"
                .format(node=self.id, vif=vif_id))
